@@ -20,10 +20,7 @@
 #define USAGE "trap [ -x ] { signal { cmdline } ... } prog..."
 #define dieusage() strerr_dieusage(100, USAGE) ;
 
-static pid_t pids[SKALIBS_NSIG + 1] ;
-static char const *const *argvs[SKALIBS_NSIG] ; /* initted with 0s */
-
-static inline void action (unsigned int i, char const *const *envp, size_t envlen)
+static inline void trap_action (unsigned int i, char const *const *envp, size_t envlen, pid_t *pids, char const *const **argvs)
 {
   if (argvs[i])
   {
@@ -48,6 +45,8 @@ static inline void action (unsigned int i, char const *const *envp, size_t envle
 
 int main (int argc, char const **argv, char const *const *envp)
 {
+  pid_t pids[SKALIBS_NSIG + 1] ;
+  char const *const *argvs[SKALIBS_NSIG] = { 0 } ;
   size_t envlen = env_len(envp) ;
   iopause_fd x = { .events = IOPAUSE_READ } ;
   sigset_t full, set ;
@@ -147,7 +146,7 @@ int main (int argc, char const **argv, char const *const *envp)
         }
         break ;
       default :
-        action(r, envp, envlen) ;
+        trap_action(r, envp, envlen, pids, argvs) ;
     }
   }
 }
